@@ -7,10 +7,7 @@ use signal_hook::iterator::Signals;
 
 /// This starts a new thread to listen for SIGWINCH signals
 #[allow(unused)]
-pub fn start_resize_thread(
-    resize_sender: Sender<()>,
-    resize_running: Arc<AtomicBool>,
-) {
+pub fn start_resize_thread(resize_sender: Sender<()>, resize_running: Arc<AtomicBool>) {
     let mut signals = Signals::new([libc::SIGWINCH]).unwrap();
     thread::spawn(move || {
         // This thread will listen to SIGWINCH events and report them.
